@@ -13,16 +13,16 @@ from mcdbot.discordcontext import DiscordContext
 from loguru import logger
 
 
-async def help_text(msg):
-    usage = usage_text[msg.x_context]
-    if msg.x_context == DiscordContext.GUILD_TEXT_CHANNEL:
+async def help_text(main, msg, context):
+    usage = usage_text[context]
+    if context == DiscordContext.GUILD_TEXT_CHANNEL:
         context = 'main text channel'
-    elif msg.x_context == DiscordContext.DM_CHANNEL:
+    elif context == DiscordContext.DM_CHANNEL:
         context = 'DMs'
-    elif msg.x_context == DiscordContext.GROUP_CHANNEL:
+    elif context == DiscordContext.GROUP_CHANNEL:
         context = 'group DMs'
     else:
-        logger.warning("[PROBABLY BUG] Context text for msg.x_context in help_text(msg) is not defined.")
+        logger.warning("[PROBABLY BUG] Context text for context in help_text(msg) is not defined.")
         context = "SOMETHING'S WRONG BRUH"
 
     return f"""```md
